==> jyou_sdk-0.2.0.tar.gz: lib/jyou_sdk.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class JyouSdk {
  static const MethodChannel _channel = MethodChannel('jyou_sdk/method');
  static const EventChannel _scanChannel = EventChannel('jyou_sdk/scan');
  static const EventChannel _connectStateChannel = EventChannel('jyou_sdk/connectState');
  static const EventChannel _temperatureChannel = EventChannel('jyou_sdk/feature/temperature');
  static const EventChannel _bloodPressureChannel = EventChannel('jyou_sdk/feature/bloodPressure');
  static const EventChannel _heartRateChannel = EventChannel('jyou_sdk/feature/heartRate');
  static const EventChannel _stepChannel = EventChannel('jyou_sdk/feature/step');
  static const EventChannel _sleepChannel = EventChannel('jyou_sdk/feature/sleep');
  static const EventChannel _exerciseChannel = EventChannel('jyou_sdk/feature/exercise');
  static const EventChannel _sensorStateChannel = EventChannel('jyou_sdk/sensorState');
  static const EventChannel _batteryChannel = EventChannel('jyou_sdk/battery');

  ///getDeviceListStream(BluetoothDevice device)
  static Stream<dynamic> get getDeviceListStream {
    return _scanChannel.receiveBroadcastStream().cast();
  }

  ///getConnectState(BluetoothDevice device)
  static Stream<dynamic> get getConnectState{
    return _connectStateChannel.receiveBroadcastStream().cast();
  }

  ///_temperatureChannel
  static Stream<dynamic> get getTemperatureStream {
    return _temperatureChannel.receiveBroadcastStream().cast();
  }

  ///_bloodPressureChannel
  static Stream<dynamic> get getBloodPressureChannelStream {
    return _bloodPressureChannel.receiveBroadcastStream().cast();
  }

  ///_heartRateChannel
  static Stream<dynamic> get getHeartRateStream {
    return _heartRateChannel.receiveBroadcastStream().cast();
  }

  ///_stepChannel
  static Stream<dynamic> get getStepStream {
    return _stepChannel.receiveBroadcastStream().cast();
  }

  ///_sleepChannel
  static Stream<dynamic> get getSleepStream {
    return _sleepChannel.receiveBroadcastStream().cast();
  }

  ///_exerciseChannel
  static Stream<dynamic> get getExerciseStream {
    return _exerciseChannel.receiveBroadcastStream().cast();
  }

  ///getSensorStateStream
  static Stream<dynamic> get getSensorStateStream {
    return _sensorStateChannel.receiveBroadcastStream().cast();
  }

  ///getBatteryStream
  static Stream<dynamic> get getBatteryStream {
    return _batteryChannel.receiveBroadcastStream().cast();
  }


  ///bind(BluetoothDevice device)
  Future<dynamic> bind() =>
      _channel.invokeMethod('bind');

  ///unbind(BluetoothDevice device)
  Future<dynamic> unbind() =>
      _channel.invokeMethod('unbind');

  ///isBound(BluetoothDevice device)
  Future isBound() =>
      _channel.invokeMethod('isBound');

  ///scan(BluetoothDevice device)
  Future<dynamic> scan() =>
      _channel.invokeMethod('scan');

  ///stopScan(BluetoothDevice device)
  Future<dynamic> stopScan() =>
      _channel.invokeMethod('stopScan');

  ///connect(BluetoothDevice device)
  Future<dynamic> connect({required String bname,required String bmac}) =>
      _channel.invokeMethod('connect',{
        'bname': bname,
        'bmac': bmac
      });

  ///disconnect(BluetoothDevice device)
  Future<dynamic> disconnect() =>
      _channel.invokeMethod('disconnect');

  ///isConnect(BluetoothDevice device)
  Future isConnect() =>
      _channel.invokeMethod('isConnect');

  ///open Temperature
  Future<dynamic> openTemperature() =>
      _channel.invokeMethod('openTemperature');

  ///close Temperature
  Future<dynamic> closeTemperature() =>
      _channel.invokeMethod('closeTemperature');

  ///open Heart Rate
  Future<dynamic> openHeartRate() =>
      _channel.invokeMethod('openHeartRate');

  ///close Heart Rate
  Future<dynamic> closeHeartRate() =>
      _channel.invokeMethod('closeHeartRate');

  ///open Blood Pressure
  Future<dynamic> openBloodPressure() =>
      _channel.invokeMethod('openBloodPressure');

  ///close Blood Pressure
  Future<dynamic> closeBloodPressure() =>
      _channel.invokeMethod('closeBloodPressure');

  ///sendNotification device
  Future<dynamic> sendNotification({required int type,required String name,required String content}) =>
      _channel.invokeMethod('sendNotification',{
        'type': type,
        'name': name,
        'content': content
      });

  ///readBattery
  Future<dynamic> readBattery() =>
      _channel.invokeMethod('readBattery');

  ///readCurrentSportData
  Future<dynamic> readCurrentSportData() =>
      _channel.invokeMethod('getcursportdata');

  ///setRemotePhoto
  Future<dynamic> callRemoteSetPhoto() =>
      _channel.invokeMethod('set_photo');

  ///callRemoteGetMutipleData
  Future<dynamic> callRemoteGetMutipleData() =>
      _channel.invokeMethod('bt_getmutipleSportData');

  ///setAlarm
  Future<dynamic> setAlarm({required int alarmId,required int enableTypeId,required int hour,required int minute,
    required int enableMonday,required int enableTuesday,required int enableWednesday,
    required int enableThursday,required int enableFriday,required int enableSaturday,
    required int enableSunday,required String content,required bool isSingle}) =>
      _channel.invokeMethod('set_alarm',{
        'alarm_id': alarmId,
        'enableType_id': enableTypeId,
        'hour': hour,
        'minute': minute,
        'enableMonday': enableMonday,
        'enableTuesday': enableTuesday,
        'enableWednesday': enableWednesday,
        'enableThursday': enableThursday,
        'enableFriday': enableFriday,
        'enableSaturday': enableSaturday,
        'enableSunday': enableSunday,
        'content': content,
        'isSingle': isSingle,
      });

  ///setRemotePhoto
  Future<dynamic> setRemotePhoto({required bool idRemotePhoto}) =>
      _channel.invokeMethod('set_photo',{
        'idRemotePhoto': idRemotePhoto,
      });
}

==> jyou_sdk-0.2.5.tar.gz: lib/jyou_sdk.dart <==

import 'dart:async';

import 'package:flutter/services.dart';

class JyouSdk {
  static const MethodChannel _channel = MethodChannel('jyou_sdk/method');
  static const EventChannel _scanChannel = EventChannel('jyou_sdk/scan');
  static const EventChannel _connectStateChannel = EventChannel('jyou_sdk/connectState');
  static const EventChannel _temperatureChannel = EventChannel('jyou_sdk/feature/temperature');
  static const EventChannel _bloodPressureChannel = EventChannel('jyou_sdk/feature/bloodPressure');
  static const EventChannel _heartRateChannel = EventChannel('jyou_sdk/feature/heartRate');
  static const EventChannel _stepChannel = EventChannel('jyou_sdk/feature/step');
  static const EventChannel _sleepChannel = EventChannel('jyou_sdk/feature/sleep');
  static const EventChannel _exerciseChannel = EventChannel('jyou_sdk/feature/exercise');
  static const EventChannel _sensorStateChannel = EventChannel('jyou_sdk/sensorState');
  static const EventChannel _batteryChannel = EventChannel('jyou_sdk/battery');
  static const EventChannel _remotePhotoChannel = EventChannel('jyou_sdk/remotePhoto');
  static const EventChannel _deviceActionChannel = EventChannel('jyou_sdk/deviceAction');

  ///getDeviceListStream(BluetoothDevice device)
  static Stream<dynamic> get getDeviceListStream {
    return _scanChannel.receiveBroadcastStream().cast();
  }

  ///getConnectState(BluetoothDevice device)
  static Stream<dynamic> get getConnectState{
    return _connectStateChannel.receiveBroadcastStream().cast();
  }

  ///_temperatureChannel
  static Stream<dynamic> get getTemperatureStream {
    return _temperatureChannel.receiveBroadcastStream().cast();
  }

  ///_bloodPressureChannel
  static Stream<dynamic> get getBloodPressureChannelStream {
    return _bloodPressureChannel.receiveBroadcastStream().cast();
  }

  ///_heartRateChannel
  static Stream<dynamic> get getHeartRateStream {
    return _heartRateChannel.receiveBroadcastStream().cast();
  }

  ///_stepChannel
  static Stream<dynamic> get getStepStream {
    return _stepChannel.receiveBroadcastStream().cast();
  }

  ///_sleepChannel
  static Stream<dynamic> get getSleepStream {
    return _sleepChannel.receiveBroadcastStream().cast();
  }

  ///_exerciseChannel
  static Stream<dynamic> get getExerciseStream {
    return _exerciseChannel.receiveBroadcastStream().cast();
  }

  ///getSensorStateStream
  static Stream<dynamic> get getSensorStateStream {
    return _sensorStateChannel.receiveBroadcastStream().cast();
  }

  ///getBatteryStream
  static Stream<dynamic> get getBatteryStream {
    return _batteryChannel.receiveBroadcastStream().cast();
  }

  ///getRemotePhotoStream
  static Stream<dynamic> get getRemotePhotoStream {
    return _remotePhotoChannel.receiveBroadcastStream().cast();
  }

  ///getDeviceActionStream
  static Stream<dynamic> get getDeviceActionStream {
    return _deviceActionChannel.receiveBroadcastStream().cast();
  }



  ///bind(BluetoothDevice device)
  Future<dynamic> bind() =>
      _channel.invokeMethod('bind');

  ///unbind(BluetoothDevice device)
  Future<dynamic> unbind() =>
      _channel.invokeMethod('unbind');

  ///isBound(BluetoothDevice device)
  Future isBound() =>
      _channel.invokeMethod('isBound');

  ///scan(BluetoothDevice device)
  Future<dynamic> scan() =>
      _channel.invokeMethod('scan');

  ///stopScan(BluetoothDevice device)
  Future<dynamic> stopScan() =>
      _channel.invokeMethod('stopScan');

  ///connect(BluetoothDevice device)
  Future<dynamic> connect({required String bname,required String bmac}) =>
      _channel.invokeMethod('connect',{
        'bname': bname,
        'bmac': bmac
      });

  ///disconnect(BluetoothDevice device)
  Future<dynamic> disconnect() =>
      _channel.invokeMethod('disconnect');

  ///isConnect(BluetoothDevice device)
  Future isConnect() =>
      _channel.invokeMethod('isConnect');

  ///open Temperature
  Future<dynamic> openTemperature() =>
      _channel.invokeMethod('openTemperature');

  ///close Temperature
  Future<dynamic> closeTemperature() =>
      _channel.invokeMethod('closeTemperature');

  ///open Heart Rate
  Future<dynamic> openHeartRate() =>
      _channel.invokeMethod('openHeartRate');

  ///close Heart Rate
  Future<dynamic> closeHeartRate() =>
      _channel.invokeMethod('closeHeartRate');

  ///open Blood Pressure
  Future<dynamic> openBloodPressure() =>
      _channel.invokeMethod('openBloodPressure');

  ///close Blood Pressure
  Future<dynamic> closeBloodPressure() =>
      _channel.invokeMethod('closeBloodPressure');

  ///sendNotification device
  Future<dynamic> sendNotification({required int type,required String name,required String content}) =>
      _channel.invokeMethod('sendNotification',{
        'type': type,
        'name': name,
        'content': content
      });

  ///readBattery
  Future<dynamic> readBattery() =>
      _channel.invokeMethod('readBattery');

  ///readCurrentSportData
  Future<dynamic> readCurrentSportData() =>
      _channel.invokeMethod('getcursportdata');

  ///setRemotePhoto
  Future<dynamic> callRemoteSetPhoto() =>
      _channel.invokeMethod('set_photo');

  ///callRemoteGetMutipleData
  Future<dynamic> callRemoteGetMutipleData({required int day}) =>
      _channel.invokeMethod('bt_getmutipleSportData',{ 'daySport': day,});

  ///setAlarm
  Future<dynamic> setAlarm({required int alarmId,required int enableTypeId,required int hour,required int minute,
    required int enableMonday,required int enableTuesday,required int enableWednesday,
    required int enableThursday,required int enableFriday,required int enableSaturday,
    required int enableSunday,required String content,required bool isSingle}) =>
      _channel.invokeMethod('set_alarm',{
        'alarm_id': alarmId,
        'enableType_id': enableTypeId,
        'hour': hour,
        'minute': minute,
        'enableMonday': enableMonday,
        'enableTuesday': enableTuesday,
        'enableWednesday': enableWednesday,
        'enableThursday': enableThursday,
        'enableFriday': enableFriday,
        'enableSaturday': enableSaturday,
        'enableSunday': enableSunday,
        'content': content,
        'isSingle': isSingle,
      });

  ///setRemotePhoto
  Future<dynamic> setRemotePhoto({required bool isRemotePhoto}) =>
      _channel.invokeMethod('set_photo',{
        'isRemotePhoto': isRemotePhoto,
      });
}
